@@ -1,12 +1,13 @@
 package Tkx::SplashScreen;
 
 use strict;
-use Tkx ();
+use warnings;
 
+our $VERSION = '0.14';
+
+use Tkx;
 use base qw(Tkx::widget Tkx::MegaConfig);
 
-our $VERSION = '0.13';
-
 __PACKAGE__->_Mega('tkx_SplashScreen');
 __PACKAGE__->_Config();
 
@@ -18,7 +19,7 @@ __PACKAGE__->_Config();
 #----------------------------------------------------------------------------
 sub _Populate {
     my ($class, $widget, $path, %opt) = @_;
-    
+
     my $self = $class->new($path)->_parent->new_toplevel(
         -name  => $path,
         -class => 'tkx_SplashScreen'
@@ -33,8 +34,8 @@ sub _Populate {
     my $data = $self->_data();
     $data->{-title}       = delete  $opt{-title};
     $data->{-image}       = delete  $opt{-image};
-    
-    $data->{-override}    = defined $opt{-override}    ? $opt{-override}    : 1;    
+
+    $data->{-override}    = defined $opt{-override}    ? $opt{-override}    : 1;
     $data->{-width}       = defined $opt{-width }      ? $opt{-width}       : 400;
     $data->{-height}      = defined $opt{-height}      ? $opt{-height}      : 300;
     $data->{-alpha}       = defined $opt{-alpha}       ? $opt{-alpha}       : 1.0;
@@ -45,10 +46,9 @@ sub _Populate {
     $data->{-topmost}     = defined $opt{-topmost}     ? $opt{-topmost}     : 0;
     $data->{-delay}       = defined $opt{-delay}       ? $opt{-delay}       : 0;
 
-    
     # Initialize
     $self->_obj_init();
-    
+
     # Widget
     return $self;
 }
@@ -61,43 +61,36 @@ sub _Populate {
 #----------------------------------------------------------------------------
 sub _obj_init {
     my ($self) = @_;
-    
-    my $data = $self->_data;
+
+    my $data = $self->_data();
 
     # Title
     if (defined $data->{-title}) {
         $self->g_wm_title($data->{-title});
     }
-    
-    
-    # Override redirect    
+
+    # Override redirect
     if ($data->{-override}) {
         $self->g_wm_overrideredirect(1);
     }
-    
-    
+
     # Alpha channel
     if ($data->{-alpha}) {
         if (Tkx::tk_windowingsystem() eq 'win32') {
             $self->g_wm_attributes(-alpha => $data->{-alpha});
         }
-        else {
-            # TODO: 
-        }
     }
-    
-    
+
     # Topmost
     if ($data->{-topmost}) {
         $self->g_wm_attributes(-topmost => $data->{-topmost});
     }
-    
+
     # Fullscreen
     if ($data->{-fullscreen}) {
         $self->g_wm_attributes(-fullscreen => $data->{-fullscreen});
     }
-    
-    
+
     # Set width/height
     my ($image_width, $image_height);
     my ($width, $height);
@@ -117,32 +110,31 @@ sub _obj_init {
     else {
         $width = $data->{-width};
     }
-    
+
     if (($data->{-height} eq 'auto') or ($data->{-height} < 0)) {
         $height = $image_height;
     }
     else {
         $height = $data->{-height};
     }
-    
-    
+
     # Set position
     my ($posx, $posy);
     
     if (($data->{-posx} eq 'auto') or ($data->{-posx} < 0)) {
-        $posx = int(($self->g_winfo_screenwidth() - $width) / 2);       
+        $posx = int(($self->g_winfo_screenwidth() - $width) / 2);
     }
     else {
         $posx = $data->{-posx};
     }
- 
-    if (($data->{-posy} eq 'auto') or ($data->{-posy} < 0)) {       
+
+    if (($data->{-posy} eq 'auto') or ($data->{-posy} < 0)) {
         $posy = int(($self->g_winfo_screenheight() - $height) / 2);
     }
     else {
         $posy = $data->{-posy};
     }
-    
+
     # Set image
     my $canvas = $data->{canvas} = $self->new_canvas(
         -width              => $width,
@@ -153,7 +145,7 @@ sub _obj_init {
     $canvas->g_pack();
     
     if ($data->{-image}) {
-        $canvas->create_image(qw(0 0), -anchor => 'nw', -image => $data->{-image});        
+        $canvas->create_image(qw(0 0), -anchor => 'nw', -image => $data->{-image});
     }
 
     # Hide on click
@@ -162,17 +154,16 @@ sub _obj_init {
             $self->hide();
         });
     }
-    
+
     # Hide on delay
     if ($data->{-delay}) {
         Tkx::after($data->{-delay}, sub {
             $self->hide();
         })
     }
-    
+
     # Set geometry 
     $self->g_wm_geometry("${width}x${height}+${posx}+${posy}");
-    
 
     # Show window
     if ($data->{-show}) {
@@ -215,10 +206,6 @@ sub canvas {
     return $self->_data->{canvas};
 }
 
-
-
-
-
 1;
 __END__
 
@@ -230,33 +217,37 @@ Tkx::SplashScreen - splashscreen megawidget for Tkx.
 
 =head1 VERSION
 
-This documentation referers to Tkx::SplashScreen version 0.11
+This documentation referers to Tkx::SplashScreen version 0.14
 
 =head1 SYNOPSYS
 
     use Tkx;
     use Tkx::SplashScreen;
     
-    my $mw = Tkx::widget->new('.');
-    $mw->g_wm_withdraw();
+    Tkx::package_require('img::png');
     
-    my $splash = $mw->new_tkx_SplashScreen(
-        -image      => Tkx::image_create_photo(-file => './splashscreen.png'),
+    my $mw = Tkx::widget->new('.');
+       $mw->g_wm_withdraw();
+    
+    my $sr = $mw->new_tkx_SplashScreen(
+        -image      => Tkx::image_create_photo(-file => './image.png'),
         -width      => 'auto',
         -height     => 'auto',
-        -posx       => 'auto',
-        -posy       => 'auto',
-        -delay      => 1000,
         -show       => 1,
-        -alpha      => 0.9,
-        -override   => 1,
+        -topmost    => 1,
     );
     
-    # Do some stuff
-    ...
+    my $cv = $sr->canvas();
+       $cv->create_text(qw(10 10), -text => 'Loading...', -anchor => 'w');
     
-    # Destroy widget
-    $splash->g_destroy();
+    # Do some stuff.
+    
+    # Destroy splash screen and show main window.
+    Tkx::after(5000 => sub {
+        $sr->g_destroy();
+        $mw->g_wm_deiconify();
+    });
+
 
 =head1 DESCRIPTION
 
@@ -267,8 +258,6 @@ appears while application is loading.
 
 The options bellow are passed through the constructor of megawidget.
 
-=head2 C<-title =E<gt> I<title>>
-
 =head2 C<-image =E<gt> I<image>>
 
 Background image.
@@ -310,6 +299,7 @@ Show splash screen after construction.
 
 =head2 C<-hideonclick =E<gt> I<hideonclick>>
 
+Hide splash screen on mouse click
 
 =head1 METHODS
 
@@ -347,7 +337,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 AUTHOR
 
-Alexander Nusov <santeri@cpan.org>
+Alexander Nusov <cpan at sancode.net>
 
 =head1 COPYRIGHTS AND LICENSE
 
